==> cxf-testutils-2.0.12.0-fuse-sources.jar: org/apache/type_test/doc/TestDerivedStructBaseStruct.java <==

package org.apache.type_test.doc;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import org.apache.type_test.types1.DerivedStructBaseStruct;


/**
 * <p>Java class for testDerivedStructBaseStruct element declaration.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;element name="testDerivedStructBaseStruct">
 *   &lt;complexType>
 *     &lt;complexContent>
 *       &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *         &lt;sequence>
 *           &lt;element name="x" type="{http://apache.org/type_test/types1}DerivedStructBaseStruct"/>
 *           &lt;element name="y" type="{http://apache.org/type_test/types1}DerivedStructBaseStruct"/>
 *         &lt;/sequence>
 *       &lt;/restriction>
 *     &lt;/complexContent>
 *   &lt;/complexType>
 * &lt;/element>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "x",
    "y"
})
@XmlRootElement(name = "testDerivedStructBaseStruct")
public class TestDerivedStructBaseStruct {

    @XmlElement(namespace = "http://apache.org/type_test/doc", required = true)
    protected DerivedStructBaseStruct x;
    @XmlElement(namespace = "http://apache.org/type_test/doc", required = true)
    protected DerivedStructBaseStruct y;

    /**
     * Gets the value of the x property.
     * 
     * @return
     *     possible object is
     *     {@link DerivedStructBaseStruct }
     *     
     */
    public DerivedStructBaseStruct getX() {
        return x;
    }

    /**
     * Sets the value of the x property.
     * 
     * @param value
     *     allowed object is
     *     {@link DerivedStructBaseStruct }
     *     
     */
    public void setX(DerivedStructBaseStruct value) {
        this.x = value;
    }

    /**
     * Gets the value of the y property.
     * 
     * @return
     *     possible object is
     *     {@link DerivedStructBaseStruct }
     *     
     */
    public DerivedStructBaseStruct getY() {
        return y;
    }

    /**
     * Sets the value of the y property.
     * 
     * @param value
     *     allowed object is
     *     {@link DerivedStructBaseStruct }
     *     
     */
    public void setY(DerivedStructBaseStruct value) {
        this.y = value;
    }

}

==> cxf-testutils-2.1.3.20-fuse-sources.jar: org/apache/type_test/doc/TestDerivedStructBaseStruct.java <==

package org.apache.type_test.doc;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import org.apache.type_test.types1.DerivedStructBaseStruct;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="x" type="{http://apache.org/type_test/types1}DerivedStructBaseStruct"/>
 *         &lt;element name="y" type="{http://apache.org/type_test/types1}DerivedStructBaseStruct"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "x",
    "y"
})
@XmlRootElement(name = "testDerivedStructBaseStruct")
public class TestDerivedStructBaseStruct {

    @XmlElement(required = true)
    protected DerivedStructBaseStruct x;
    @XmlElement(required = true)
    protected DerivedStructBaseStruct y;

    /**
     * Gets the value of the x property.
     * 
     * @return
     *     possible object is
     *     {@link DerivedStructBaseStruct }
     *     
     */
    public DerivedStructBaseStruct getX() {
        return x;
    }

    /**
     * Sets the value of the x property.
     * 
     * @param value
     *     allowed object is
     *     {@link DerivedStructBaseStruct }
     *     
     */
    public void setX(DerivedStructBaseStruct value) {
        this.x = value;
    }

    /**
     * Gets the value of the y property.
     * 
     * @return
     *     possible object is
     *     {@link DerivedStructBaseStruct }
     *     
     */
    public DerivedStructBaseStruct getY() {
        return y;
    }

    /**
     * Sets the value of the y property.
     * 
     * @param value
     *     allowed object is
     *     {@link DerivedStructBaseStruct }
     *     
     */
    public void setY(DerivedStructBaseStruct value) {
        this.y = value;
    }

}
